#
# spec file for package spark
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017 cadenzajon
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sname 	spark
%define confdir	%{_sysconfdir}/%{sname}
%define sparkdir	%{_datadir}/%{sname}
%define workdir	%{_rundir}/%{sname}-work
%define logdir	%{_localstatedir}/log/%{sname}
%define workername %{sname}-worker
%define mastername %{sname}-master
Name:           %{sname}
Version:        1.6.3
Release:        29.1
Summary:        Apache Spark 1.6.3
License:        Apache-2.0
Group:          Development/Libraries/Java
Url:            http://spark.apache.org/
Source0:        http://apache.org/dist/spark/spark-1.6.3/spark-1.6.3.tgz
Source1:        build.sh
Source2:        %{workername}.service
Source3:        %{mastername}.service
Source4:        http://central.maven.org/maven2/org/drizzle/jdbc/drizzle-jdbc/1.4/drizzle-jdbc-1.4.jar
BuildRequires:  java-1_8_0-openjdk
BuildRequires:  java-1_8_0-openjdk-devel
BuildRequires:  openstack-suse-macros
BuildRequires:  spark-kit = %{version}
BuildRequires:  tar
BuildRequires:  xz
#Provides:       %{sname}
Requires:       java-1_8_0-openjdk
Requires(pre):  pwdutils
BuildArch:      noarch

%description
This is an installable package containing Apache Spark.

%prep
%setup -q -c -n src
cp -f %{SOURCE1} .
cp -Rf %{_datadir}/tetra ../kit

%build
cd ..
sh src/build.sh

%install
export NO_BRP_CHECK_BYTECODE_VERSION=true
install -d -m 755 %{buildroot}%{sparkdir}
cp -a %{name}-%{version}/dist/* %{buildroot}%{sparkdir}
install -D -m 644 %{name}-%{version}/external/kafka/target/spark-streaming-kafka_2.10-1.6.3.jar %{buildroot}%{sparkdir}/lib/spark-streaming-kafka.jar
install -D -m 644 %{SOURCE4} %{buildroot}%{sparkdir}/lib/drizzle-jdbc-1.3.jar

install -d -m 755 %{buildroot}%{_unitdir}
install -D -m 444 %{SOURCE2} %{buildroot}%{_unitdir}/%{workername}.service
install -D -m 444 %{SOURCE3} %{buildroot}%{_unitdir}/%{mastername}.service

install -d -m 755 %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{workername}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{mastername}

install -d -m 755 %{buildroot}%{_bindir}
ln -s %{sparkdir}/bin/spark-submit %{buildroot}%{_bindir}/spark-submit
ln -s %{sparkdir}/bin/spark-class %{buildroot}%{_bindir}/spark-class
ln -s %{sparkdir}/bin/spark-shell %{buildroot}%{_bindir}/spark-shell
ln -s %{sparkdir}/bin/spark-sql %{buildroot}%{_bindir}/spark-sql

sed -i '2iSPARK_HOME=%{_datadir}/spark' %{buildroot}%{sparkdir}/bin/spark-class
sed -i '2iSPARK_CONF_DIR=%{_sysconfdir}/spark' %{buildroot}%{sparkdir}/bin/spark-class

install -d -m 755 %{buildroot}%{logdir}

install -d -m 755 %{buildroot}%{confdir}
install -D -m 644 %{name}-%{version}/dist/conf/spark-defaults.conf.template %{buildroot}%{confdir}/spark-defaults.conf
install -D -m 644 %{name}-%{version}/dist/conf/spark-env.sh.template %{buildroot}%{confdir}/spark-env.sh

install -d -m 755 %{buildroot}%{workdir}
ln -s %{workdir} %{buildroot}%{sparkdir}/work

%pre
%openstack_pre_user_group_create %{sname} %{sname}
%service_add_pre %{workername}.service
%service_add_pre %{mastername}.service

%post
%service_add_post %{workername}.service
%service_add_post %{mastername}.service

%preun
%service_del_preun %{workername}.service
%service_del_preun %{mastername}.service

%postun
%service_del_postun %{workername}.service
%service_del_postun %{mastername}.service

%files
%defattr(-,root,root)
%{sparkdir}
%{_unitdir}/*
%{_sbindir}/*
%{_bindir}/*
%attr(-,spark,spark) %dir %{confdir}
%attr(-,spark,spark) %config %{confdir}/*
%attr(-,spark,spark) %dir %{logdir}
%attr(-,spark,spark) %dir %{workdir}

%changelog
* Fri Feb 23 2018 dmueller@suse.com
- cleanup spec file
* Fri Feb 23 2018 jodavis@suse.com
- Fix spark-worker.service to use port 7077, avoiding conflict (bsc#1081275)
* Mon Feb 19 2018 tbechtold@suse.com
- Fix ExecStartPre bash syntax in spark-worker.service (bsc#1081275)
* Mon Jul 24 2017 jbrownell@suse.com
- Initial package
